# Getting Started

> Getting started with OpenHands Cloud.

## Accessing OpenHands Cloud

OpenHands Cloud is the hosted cloud version of OpenHands. To get started with OpenHands Cloud,
visit [app.all-hands.dev](https://app.all-hands.dev).

You'll be prompted to connect with your GitHub, GitLab or Bitbucket account:

1. Click `Log in with GitHub`, `Log in with GitLab` or `Log in with Bitbucket`.
2. Review the permissions requested by OpenHands and authorize the application.
   * OpenHands will require certain permissions from your account. To read more about these permissions,
     you can click the `Learn more` link on the authorization page.
3. Review and accept the `terms of service` and select `Continue`.

## Next Steps

Once you've connected your account, you can:

* [Use OpenHands with your GitHub repositories](/openhands/usage/cloud/github-installation).
* [Use OpenHands with your GitLab repositories](/openhands/usage/cloud/gitlab-installation).
* [Use OpenHands with your Bitbucket repositories](/openhands/usage/cloud/bitbucket-installation).
* [Learn about the Cloud UI](/openhands/usage/cloud/cloud-ui).
* [Install the OpenHands Slack app](/openhands/usage/cloud/slack-installation).


---

> To find navigation and other pages in this documentation, fetch the llms.txt file at: https://docs.openhands.dev/llms.txt